<?php
// Load WordPress environment
require_once('../wp-load.php');
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Posts</title>
    <link rel="stylesheet" href="styles.css?v=1">
    <link href="https://fonts.googleapis.com/css2?family=Noto+Sans:wght@400;700&family=Anek+Tamil:wght@400;700&display=swap" rel="stylesheet">
</head>
<body class="light-theme">

<div class="top-bar">
    <div>My App</div>
    <div class="text-size-buttons">
        <button id="increase-text">A+</button>
        <button id="decrease-text">A-</button>
        <button class="theme-toggle-button" id="theme-toggle">Toggle Theme</button>
    </div>
</div>

<div class="container">
    <div class="left-pane">
        <div>
            <label for="search-box">Search Posts:</label>
            <input type="text" id="search-box" placeholder="Enter search term" style="max-width: 100%;">
        </div>
        <div style="flex: 1; display: flex; flex-direction: column;">
            <label for="post-list">Select Post:</label>
            <select id="post-list" size="10" style="flex: 1;"></select>
            <div id="pagination" style="margin-top: 10px;">
                <button id="next-post">Next Post</button>
            </div>
        </div>
    </div>

    <div class="right-pane">
        <div id="post-content"></div>
    </div>
</div>

<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script>
$(document).ready(function() {
    var currentPage = 1;
    var currentFontSize = 16;

    function loadPosts(data, append = false) {
        var postList = $('#post-list');
        var postContent = $('#post-content');

        if (!append) {
            postList.empty();
            postContent.empty();
            currentPage = 1;
        }

        $.ajax({
            url: '../wp-json/wp/v2/posts',
            data: data,
            success: function(posts) {
                if (posts.length > 0) {
                    $.each(posts, function(index, post) {
                        postList.append($('<option>', {
                            value: post.id,
                            text: post.title.rendered
                        }));
                    });

                    if (posts.length == 20) {
                        $('#pagination').append('<button id="load-more" data-page="' + (currentPage + 1) + '">Load More</button>');
                    } else {
                        $('#pagination').empty();
                    }
                } else {
                    $('#pagination').empty();
                }
            }
        });
    }

    loadPosts({ per_page: 20, order: 'asc', orderby: 'id' });

    $('#search-box').on('keypress', function(e) {
        if (e.which == 13) {
            var searchTerm = $(this).val();
            loadPosts({ search: searchTerm, per_page: 20, order: 'asc', orderby: 'id' });
        }
    });

    $('#post-list').on('change', function() {
        var postId = $(this).val();
        var postContent = $('#post-content');

        postContent.empty();

        if (postId) {
            $.ajax({
                url: '../wp-json/wp/v2/posts/' + postId,
                success: function(post) {
                    postContent.html('<h2>' + post.title.rendered + '</h2><br>' + post.content.rendered);
                }
            });
        }
    });

    $(document).on('click', '#load-more', function() {
        var nextPage = $(this).data('page');
        var data = { page: nextPage, per_page: 20, order: 'asc', orderby: 'id' };

        currentPage = nextPage;
        loadPosts(data, true);
    });

    $('#next-post').on('click', function() {
        var postList = $('#post-list');
        var selectedIndex = postList.prop('selectedIndex');
        var nextIndex = selectedIndex + 1;

        if (nextIndex < postList.children().length) {
            postList.prop('selectedIndex', nextIndex);
            postList.trigger('change');
        }
    });

    $('#increase-text').on('click', function() {
        currentFontSize += 1;
        $('#post-content').css('font-size', currentFontSize + 'px');
    });

    $('#decrease-text').on('click', function() {
        currentFontSize -= 1;
        $('#post-content').css('font-size', currentFontSize + 'px');
    });

    function setTheme(theme) {
        $('body').removeClass('light-theme dark-theme').addClass(theme);
        document.cookie = "theme=" + theme + "; path=/";
    }

    var savedTheme = document.cookie.split('; ').find(row => row.startsWith('theme=')).split('=')[1];
    if (savedTheme) {
        setTheme(savedTheme);
    }

    $('#theme-toggle').on('click', function() {
        var currentTheme = $('body').hasClass('light-theme') ? 'light-theme' : 'dark-theme';
        var newTheme = currentTheme === 'light-theme' ? 'dark-theme' : 'light-theme';
        setTheme(newTheme);
    });
});
</script>

</body>
</html>
